searchData={"items":[{"type":"module","title":"FunctionGenerator","doc":"","ref":"FunctionGenerator.html"},{"type":"module","title":"Vectorex","doc":"This module is a container for controls for a full text search for postgres.\n\nIt provides a fluent api to build full text search queries which can be transformed to a string\nthat can be passed for execution using `&to_sql/1`\n\n\nThe module contains four functions that can be used to build the query\n  1. ts_and\n  2. ts_or\n  3. ts_not\n  4. ts_followed_by\n\nSame functions exist in Vectorex.Subquery\n\nDepending on the function you pass to `new/2`, the behaviour changes. If the control\nis supported by the function, we append it to the query. If not, the parameter is ignored.\n\nCheck [the official documentation](https://www.postgresql.org/docs/current/textsearch-controls.html)\nto verify which controls are supported by the function\n\nOnly to_tsquery supports all 4 controls.\n\nYou can create a new instance of Vectorex using `new/2` by passing the postgres function\nyou want to use and the parameter\n\nAvailable Postgres functions are: :to_tsquery, :phraseto_tsquery, :plainto_tsquery, :websearch_to_tsquery\n\nAfter that, you can start building the query.","ref":"Vectorex.html"},{"type":"module","title":"Building queries - Vectorex","doc":"You can do that by using pipes\n```elixir\n# and \nVectorex.new(:to_tsquery, \"elixir\") |> Vectorex.ts_and(\"ocaml\")\n\n# or\nVectorex.new(:to_tsquery, \"elixir\") |> Vectorex.ts_or(\"ocaml\")\n\n# not\nVectorex.new(:to_tsquery, \"elixir\") |> Vectorex.ts_not(\"ocaml\")\n\n# followed_by\nVectorex.new(:to_tsquery, \"elixir\") |> Vectorex.ts_followed_by(\"ocaml\")\n```\n\nObviously, you can pipe multiple times\n\n```elixir\nVectorex.new(:to_tsquery, \"elixir\") \n|> Vectorex.ts_and(\"ocaml\")\n|> Vectorex.ts_and(\"scala\")\n```\n\nOr you can use a list\n\n```elixir\nVectorex.new(:to_tsquery, \"elixir\") \n|> Vectorex.ts_and([\"ocaml\", \"scala\"])\n```","ref":"Vectorex.html#module-building-queries"},{"type":"module","title":"Building subqueries - Vectorex","doc":"You can also group operators together using `Vectorex.Subquery.new/1`. \nYou can do this if you want parentheses around your terms\n\n```elixir\ninner =\n  Vectorex.Subquery.new(\"ocaml\")\n  |> Vectorex.Subquery.ts_and(\"scala\")\n\nresult =\n  Vectorex.new(:to_tsquery, \"elixir\")\n  |> Vectorex.ts_and(inner)\n```\n\nSubqueries also support the list option\n\n```elixir\ninner =\n  Vectorex.Subquery.new(\"ocaml\")\n  |> Vectorex.Subquery.ts_or([\"scala\", \"haskell\"])\n\nresult =\n  Vectorex.new(:to_tsquery, \"elixir\")\n  |> Vectorex.ts_and(inner)\n```\n\nWe can also pass a list of subqueries\n\n```elixir\ninner =\n  Vectorex.Subquery.new(\"ocaml\")\n  |> Vectorex.Subquery.ts_or([\"scala\", \"haskell\"])\n\ninner2 =\n  Vectorex.Subquery.new(\"java\")\n  |> Vectorex.Subquery.ts_or(\"c#\")\n\nresult =\n  Vectorex.new(:to_tsquery, \"elixir\")\n  |> Vectorex.ts_and([inner, inner2])\n```","ref":"Vectorex.html#module-building-subqueries"},{"type":"module","title":"Converting to sql - Vectorex","doc":"After we build the query we want, we need to convert it to a string. We can do that using `to_sql/1`\n\n\nWe can use that string in an Ecto fragment for execution \n\n```elixir\nvectorex = Vectorex.new(:to_tsquery, \"elixir\")\n\nfrom e in Event,\n    where: fragment(\"textsearchable_index_col @@ to_tsquery(?)\", ^Vectorex.to_sql(vectorex))\n```","ref":"Vectorex.html#module-converting-to-sql"},{"type":"function","title":"Vectorex.new/2","doc":"Creates a new Vectorex instance which can be used to build a full text search query","ref":"Vectorex.html#new/2"},{"type":"function","title":"Examples - Vectorex.new/2","doc":"iex> Vectorex.new(:to_tsquery, \"elixir\")    \n    %Vectorex{params: [\"elixir\"], function: :to_tsquery}\n\n    iex> Vectorex.new(:phraseto_tsquery, \"elixir\")    \n    %Vectorex{params: [\"elixir\"], function: :phraseto_tsquery}\n\n    iex> Vectorex.new(:plainto_tsquery, \"elixir\")    \n    %Vectorex{params: [\"elixir\"], function: :plainto_tsquery}\n\n    iex> Vectorex.new(:websearch_to_tsquery, \"elixir\")    \n    %Vectorex{params: [\"elixir\"], function: :websearch_to_tsquery}","ref":"Vectorex.html#new/2-examples"},{"type":"function","title":"Vectorex.to_sql/1","doc":"Transforms a Vectorex instance to a sql string","ref":"Vectorex.html#to_sql/1"},{"type":"function","title":"Examples - Vectorex.to_sql/1","doc":"iex> Vectorex.new(:to_tsquery, \"elixir\") |> Vectorex.ts_and(\"ocaml\") |> Vectorex.ts_and(\"haskell\") |>  Vectorex.to_sql()\n    \"elixir & ocaml & haskell\"\n\n    iex> Vectorex.new(:to_tsquery, \"elixir\") |> Vectorex.ts_and(Vectorex.Subquery.new(\"ocaml\") |> Vectorex.Subquery.ts_or(\"scala\")) |> Vectorex.to_sql()\n    \"elixir & (ocaml | scala)\"","ref":"Vectorex.html#to_sql/1-examples"},{"type":"function","title":"Vectorex.ts_and/2","doc":"Adds a AND clause.\n\nIf the operator is supported by the text search control, the parameter is applied to the builder. If not the parameter is ignored.","ref":"Vectorex.html#ts_and/2"},{"type":"function","title":"Vectorex.ts_followed_by/2","doc":"Adds a FOLLOWED BY clause.\n\nIf the operator is supported by the text search control, the parameter is applied to the builder. If not the parameter is ignored.","ref":"Vectorex.html#ts_followed_by/2"},{"type":"function","title":"Vectorex.ts_not/2","doc":"Adds a NOT clause.\n\nIf the operator is supported by the text search control, the parameter is applied to the builder. If not the parameter is ignored.","ref":"Vectorex.html#ts_not/2"},{"type":"function","title":"Vectorex.ts_or/2","doc":"Adds a OR clause.\n\nIf the operator is supported by the text search control, the parameter is applied to the builder. If not the parameter is ignored.","ref":"Vectorex.html#ts_or/2"},{"type":"type","title":"Vectorex.t/0","doc":"","ref":"Vectorex.html#t:t/0"},{"type":"module","title":"Vectorex.Subquery","doc":"","ref":"Vectorex.Subquery.html"},{"type":"function","title":"Vectorex.Subquery.new/1","doc":"Creates a new Vectorex.Subquery instance","ref":"Vectorex.Subquery.html#new/1"},{"type":"function","title":"Vectorex.Subquery.ts_and/2","doc":"Adds a AND clause.\n\nIf the operator is supported by the text search control, the parameter is applied to the builder. If not the parameter is ignored.","ref":"Vectorex.Subquery.html#ts_and/2"},{"type":"function","title":"Vectorex.Subquery.ts_followed_by/2","doc":"Adds a FOLLOWED BY clause.\n\nIf the operator is supported by the text search control, the parameter is applied to the builder. If not the parameter is ignored.","ref":"Vectorex.Subquery.html#ts_followed_by/2"},{"type":"function","title":"Vectorex.Subquery.ts_not/2","doc":"Adds a NOT clause.\n\nIf the operator is supported by the text search control, the parameter is applied to the builder. If not the parameter is ignored.","ref":"Vectorex.Subquery.html#ts_not/2"},{"type":"function","title":"Vectorex.Subquery.ts_or/2","doc":"Adds a OR clause.\n\nIf the operator is supported by the text search control, the parameter is applied to the builder. If not the parameter is ignored.","ref":"Vectorex.Subquery.html#ts_or/2"},{"type":"type","title":"Vectorex.Subquery.t/0","doc":"","ref":"Vectorex.Subquery.html#t:t/0"},{"type":"extras","title":"Vectorex","doc":"# Vectorex\n\nVectorex is a builder for [full text search controls](https://www.postgresql.org/docs/current/textsearch-controls.html) for Postgres.\nInstead of concatenating strings to build a `ts_vector`, Vectorex provides a minimal API to do it fluently.\n\nAfter building the query, you can use `to_sql` to convert it to the string that the database expects and parses.\n\n#","ref":"readme.html"},{"type":"extras","title":"Examples - Vectorex","doc":"Starting with the simplest case where we want to create q `ts_query` which will match the word `elixir`\n\n```elixir\nvectorex = Vectorex.new(:to_tsquery, \"elixir\")\n```\n\nWe can add a case where we want to also match the word *ocaml*\n\n```elixir\nvectorex = Vectorex.ts_and(vectorex, \"ocaml\")\n```\n\nWe also want to match *scala* and not only *ocaml*\n\n```elixir\nvectorex = Vectorex.ts_and(vectorex, \"ocaml\") |> Vectorex.ts_and(\"ocaml\")\n```\n\nMaybe we want to match scala and ocaml or *haskell*\n\n```elixir\nvectorex = Vectorex.ts_and(vectorex, \"ocaml\") \n|> Vectorex.ts_and(\"ocaml\")\n|> Vectorex.ts_or(\"haskell\")\n```\n\nWe can use subqueries to group controls together. Lets say we want to match (scala and ocaml) or *haskell*\n```elixir\nsubquery = Vectorex.Subquery.new(\"ocaml\")\n|> Vectorex.Subquery.ts_and(\"scala\")\n\nvectorex = Vectorex.ts_and(vectorex, \"ocaml\") \n|> Vectorex.ts_and(subquery)\n|> Vectorex.ts_or(\"haskell\")\n```\n\n\n#","ref":"readme.html#examples"},{"type":"extras","title":"Converting to a string - Vectorex","doc":"After we build the query, we can use `to_sql` to convert it to a string and pass it to Ecto for example for execution\n\n```elixir\n    vectorex = Vectorex.new(:to_tsquery, \"elixir\")\n\n    from e in Event,\n        where: fragment(\"textsearchable_index_col @@ to_tsquery(?)\", ^Vectorex.to_sql(vectorex))\n```\n\nYou can find more examples in [documentation](https://hexdocs.pm/vectorex/Vectorex.html)","ref":"readme.html#converting-to-a-string"},{"type":"extras","title":"Installation - Vectorex","doc":"```elixir\ndef deps do\n  [\n    {:vectorex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown"}